@@ -4,14 +4,13 @@
 #'@param libname a character string giving the library directory where
 #'@param pkgname a character string giving the name of the package.
 .onAttach<-function(libname,pkgname){
-    packageStartupMessage("Welcome to package ztable ver 0.1.3")
+    packageStartupMessage("Welcome to package ztable ver 0.1.4")
 }
 
 .onLoad<-function(libname,pkgname){
-
     options(ztable.include.rownames=TRUE)
     options(ztable.include.colnames=TRUE)
-    options(ztable.type="latex")
+    options(ztable.type="viewer")
     options(ztable.color="black")
     options(ztable.show.heading=TRUE)
     options(ztable.show.footer=TRUE)
